@@ -34,4 +34,6 @@ def choose(choices, title=None):
                     selected = max(0, selected - 1)
                 case k if k in ('x', '\x1b'):
                     break
+        win.clear()
+        win.refresh()
         return choice
